Welcome to ClientVPS Mirrors

Help for package beans
Title: Data on Dried Beans
Version: 0.1.0
Description: These data contain morphological image measurements for dried beans from Koklu and Ozkan (2020) <doi:10.1016/j.compag.2020.105507>.
License: MIT + file LICENSE
Depends: R (≥ 2.10)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.1
Suggests: spelling
Language: en-US
NeedsCompilation: no
Packaged: 2021-07-08 20:20:46 UTC; max
Author: Max Kuhn ORCID iD [aut, cre]
Maintainer: Max Kuhn <mxkuhn@gmail.com>
Repository: CRAN
Date/Publication: 2021-07-09 09:00:08 UTC

Dry beans

Description

Dry beans

Details

Koklu and Ozkan (2020) describe a data set where images of beans were segmented and quantified. There are 13,611 beans quantified using 16 morphologic image features. The variety of each bean was labeled as one of six values (in the column class).

Value

beans

a tibble

Koklu, M, and IA Ozkan. 2020. Multiclass Classification of Dry Beans Using Computer Vision and Machine Learning Techniques.Computers and Electronics in Agriculture, 174: 105507. doi: 10.1016/j.compag.2020.105507, https://www.muratkoklu.com/datasets/

Examples

data(beans)
str(beans)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.